#!/usr/bin/env python3

import os
import sys

from ki_errors import ParseError
from ki_lexer import KiLexer
from ki_parser import KiParser

def print_usage(error_msg=None):
    program_name = os.path.basename(sys.argv[0])
    if error_msg:
        sys.stderr.write(error_msg.join(('\n', '\n')))
    usage_msg = '\nUsage: {} [ defs_file ] [ input_file ]\n\n'
    sys.stderr.write(usage_msg.format(program_name))
    sys.exit(2)

def parse(defs_file, input_file):
    parser = KiParser(defs_file, input_file)
    for node in parser.ast_nodes:
        if node is None:
            break
        print(node)

def main():
    if len(sys.argv) != 3:
        print_usage()
    defs_file, input_file = sys.argv[1:]
    for file_path in (defs_file, input_file):
        if not os.path.isfile(file_path):
            error_msg = '{} is not a file'
            print_usage(error_msg.format(file_path))
        if not os.access(input_file, os.R_OK):
            error_msg = 'Cannot open file {} for reading'
            print_usage(error_msg.format(file_path))
    # lexer = KiLexer(defs_file, input_file)
    # for token in lexer.tokens:
    #     print(token)
    try:
        parse(defs_file, input_file)
    except ParseError as e:
        raise
        print(e.args[0])
        sys.exit(1)
    except:
        raise

main()
